searchData={"items":[{"type":"module","title":"AshMoney","doc":"`AshMoney` provides a type for working with money in your Ash resources.\n\nIt also provides an `AshPostgres.Extension` that can be used to add support for\nmoney types and operators to your Postgres database.","ref":"AshMoney.html"},{"type":"module","title":"AshMoney.Types.Money","doc":"A money type for Ash that uses the `ex_money` library.\n\nWhen constructing a composite type, use a tuple in the following structure:\n\n`composite_type(%{currency: \"USD\", amount: Decimal.new(\"0\")}}, AshMoney.Types.Money)`\n\nIf you've added a custom type, like `:money`:\n\n```elixir\ncomposite_type(%{currency: \"USD\", amount: Decimal.new(\"0\")}}, :money)\n```","ref":"AshMoney.Types.Money.html"},{"type":"module","title":"AshMoney.AshPostgresExtension","doc":"Installs the `money_with_currency` type and operators/functions for Postgres.","ref":"AshMoney.AshPostgresExtension.html"},{"type":"function","title":"AshMoney.AshPostgresExtension.extension/0","doc":"","ref":"AshMoney.AshPostgresExtension.html#extension/0"},{"type":"function","title":"AshMoney.AshPostgresExtension.install/1","doc":"","ref":"AshMoney.AshPostgresExtension.html#install/1"},{"type":"function","title":"AshMoney.AshPostgresExtension.uninstall/1","doc":"","ref":"AshMoney.AshPostgresExtension.html#uninstall/1"},{"type":"module","title":"Comparable.Type.Decimal.To.Money","doc":"","ref":"Comparable.Type.Decimal.To.Money.html"},{"type":"module","title":"Comparable.Type.Float.To.Money","doc":"","ref":"Comparable.Type.Float.To.Money.html"},{"type":"module","title":"Comparable.Type.Integer.To.Money","doc":"","ref":"Comparable.Type.Integer.To.Money.html"},{"type":"module","title":"Comparable.Type.Money.To.Decimal","doc":"","ref":"Comparable.Type.Money.To.Decimal.html"},{"type":"module","title":"Comparable.Type.Money.To.Float","doc":"","ref":"Comparable.Type.Money.To.Float.html"},{"type":"module","title":"Comparable.Type.Money.To.Integer","doc":"","ref":"Comparable.Type.Money.To.Integer.html"},{"type":"module","title":"Comparable.Type.Money.To.Money","doc":"","ref":"Comparable.Type.Money.To.Money.html"},{"type":"extras","title":"Home","doc":"![Logo](https://github.com/ash-project/ash/blob/main/logos/cropped-for-header-black-text.png?raw=true#gh-light-mode-only)\n![Logo](https://github.com/ash-project/ash/blob/main/logos/cropped-for-header-white-text.png?raw=true#gh-dark-mode-only)\n\n![Elixir CI](https://github.com/ash-project/ash_money/workflows/CI/badge.svg)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n[![Hex version badge](https://img.shields.io/hexpm/v/ash_money.svg)](https://hex.pm/packages/ash_money)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/ash_money)\n\n# AshMoney\n\nWelcome! This is the extension for working with money types in [Ash](https://hexdocs.pm/ash). This is a thin wrapper around the very excellent [ex_money](https://hexdocs.pm/ex_money). It provides:\n\n- An `Ash.Type` for representing `Money`\n- An `AshPostgres.Extension` for supporting common money operations directly in the database\n- An implementation of `Comp` for `%Money{}`, allowing Ash to compare them.","ref":"readme.html"},{"type":"extras","title":"Tutorials - Home","doc":"- [Getting Started with AshMoney](documentation/tutorials/getting-started-with-ash-money.md)","ref":"readme.html#tutorials"},{"type":"extras","title":"Getting Started With AshMoney","doc":"# Getting Started With AshMoney","ref":"getting-started-with-ash-money.html"},{"type":"extras","title":"Bring in the ash_money dependency - Getting Started With AshMoney","doc":"```elixir\ndef deps()\n  [\n    ...\n    {:ash_money, \"~> 0.1.6\"}\n  ]\nend\n```","ref":"getting-started-with-ash-money.html#bring-in-the-ash_money-dependency"},{"type":"extras","title":"Setup - Getting Started With AshMoney","doc":"The primary thing that AshMoney provides is `AshMoney.Types.Money`. This is backed by `ex_money`. You can use it out of the box like so:\n\n```elixir\nattribute :balance, AshMoney.Types.Money\n```","ref":"getting-started-with-ash-money.html#setup"},{"type":"extras","title":"Add to known types - Getting Started With AshMoney","doc":"To support money operations in runtime expressions, which use `Ash`'s operator overloading feature, we have to tell Ash about the `Ash.Type.Money` using the `known_type` configuration.\n\n```\nconfig :ash, :known_types, [AshMoney.Types.Money]\n```","ref":"getting-started-with-ash-money.html#add-to-known-types"},{"type":"extras","title":"Referencing with `:money` - Getting Started With AshMoney","doc":"You can add it to your compile time list of types for easier reference:\n\n```elixir\nconfig :ash, :custom_types, money: AshMoney.Types.Money\n```\n\nThen compile ash again, `mix deps.compile ash --force`, and refer to it like so:\n\n```elixir\nattribute :balance, :money\n```","ref":"getting-started-with-ash-money.html#referencing-with-money"},{"type":"extras","title":"AshPostgres Support - Getting Started With AshMoney","doc":"Add the `:ex_money_sql` dependency to your `mix.exs` file.\n\nThanks to `ex_money_sql`, there are excellent tools for lowering support for money into your postgres database. This allows for things like aggregates that sum amounts, and referencing money in expressions:\n\n```elixir\nsum :sum_of_usd_balances, :accounts, :balance do\n  filter expr(\n    fragment(\"(?).currency_code\", balance) == \"USD\"\n  )\nend\n```\n\nTo install it, add `AshMoney.AshPostgresExtension` to your list of `installed_extensions` in your repo, and generate migrations.\n\n```elixir\ndefmodule YourRepo do\n  def installed_extensions do\n    [..., AshMoney.AshPostgresExtension]\n  end\nend\n```","ref":"getting-started-with-ash-money.html#ashpostgres-support"},{"type":"extras","title":"AshGraphql Support - Getting Started With AshMoney","doc":"Add the following to your schema file:\n\n```elixir\n  object :money do\n    field(:amount, non_null(:decimal))\n    field(:currency, non_null(:string))\n  end\n\n  input_object :money do\n    field(:amount, non_null(:decimal))\n    field(:currency, non_null(:string))\n  end\n```","ref":"getting-started-with-ash-money.html#ashgraphql-support"},{"type":"extras","title":"Limitations - Getting Started With AshMoney","doc":"Support for using built in operators with data layers that don't support it. For example, `expr(money + money)` will work in `AshPostgres`, but not when using `Ash.DataLayer.Ets`. \nWe need to make built in functions extensible by type to make this work.","ref":"getting-started-with-ash-money.html#limitations"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.1.6](https://github.com/ash-project/ash_money/compare/v0.1.6-rc.2...v0.1.6) (2024-05-10)\n\n\n\n\n## [v0.1.6-rc.2](https://github.com/ash-project/ash_money/compare/v0.1.6-rc.1...v0.1.6-rc.2) (2024-05-05)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* update ash_postgres dependency and fix version numbers in extension\n\n## [v0.1.6-rc.1](https://github.com/ash-project/ash_money/compare/v0.1.6-rc.0...v0.1.6-rc.1) (2024-04-29)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* add `Comp` implementation for money\n\n* support casting atomic in money type\n\n## [v0.1.6-rc.0](https://github.com/ash-project/ash_money/compare/v0.1.5...v0.1.6-rc.0) (2024-04-01)\n\n\n\n\n## [v0.1.5](https://github.com/ash-project/ash_money/compare/v0.1.4...v0.1.5) (2024-04-01)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* remove duplicate money mult postgres install (#3)\n\n## [v0.1.4](https://github.com/ash-project/ash_money/compare/v0.1.3...v0.1.4) (2024-01-04)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* support new operator overrides and multiplication\n\n## [v0.1.3](https://github.com/ash-project/ash_money/compare/v0.1.2...v0.1.3) (2023-12-06)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* typespecs and upgrade `ash_graphql`\n\n## [v0.1.2](https://github.com/ash-project/ash_money/compare/v0.1.1...v0.1.2) (2023-12-04)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* add composite type storage_alias","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* add more optional deps for proper compile order\n\n* docs & optional deps\n\n* support new `Ash.Type` composite type callbacks\n\n## [v0.1.1](https://github.com/ash-project/ash_money/compare/v0.1.0...v0.1.1) (2023-11-27)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* handle missing `ex_money_sql` better\n\n## [v0.1.0](https://github.com/ash-project/ash_money/compare/v0.1.0...v0.1.0) (2023-11-27)\n\n* Initial Release","ref":"changelog.html#bug-fixes"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}